@@ -2,7 +2,7 @@
 # Warning message when there is a mismatch between metrics wavelengths
 # and data wavelengths.
 #---------------------------------------------------------------------
-msg_warning_wavelength <- function(){
+msg_warning_wavelength <- function() {
   msg <- "This metric uses either excitation or emission wavelengths that were not present in the data. Data has been interpolated to fit the requested wavelengths."
   return(msg)
 }
@@ -19,27 +19,22 @@ msg_warning_wavelength <- function(){
 #' @export
 #' @examples
 #' file <- system.file("extdata/cary/scans_day_1/", "sample1.csv", package = "eemR")
-#' eem <- eem_read(file)
+#' eem <- eem_read(file, import_function = "cary")
 #'
 #' eem_fluorescence_index(eem)
-
-eem_fluorescence_index <- function(eem, verbose = TRUE){
-
+eem_fluorescence_index <- function(eem, verbose = TRUE) {
   stopifnot(.is_eemlist(eem) | .is_eem(eem))
 
   ## It is a list of eems, then call lapply
-  if(.is_eemlist(eem)){
-
+  if (.is_eemlist(eem)) {
     res <- lapply(eem, eem_fluorescence_index, verbose = verbose)
     res <- dplyr::bind_rows(res)
 
     return(res)
   }
 
-  if(!all(370 %in% eem$ex & c(450, 500) %in% eem$em) & verbose){
-
+  if (!all(370 %in% eem$ex & c(450, 500) %in% eem$em) & verbose) {
     warning(msg_warning_wavelength(), call. = FALSE)
-
   }
 
   fluo_450 <- pracma::interp2(eem$ex, eem$em, eem$x, 370, 450)
@@ -48,7 +43,6 @@ eem_fluorescence_index <- function(eem, verbose = TRUE){
   fi <- fluo_450 / fluo_500
 
   return(data.frame(sample = eem$sample, fi = fi, stringsAsFactors = FALSE))
-
 }
 
 #' Extract fluorescence peaks
@@ -83,18 +77,15 @@ eem_fluorescence_index <- function(eem, verbose = TRUE){
 #'
 #' @examples
 #' file <- system.file("extdata/cary/scans_day_1/", "sample1.csv", package = "eemR")
-#' eem <- eem_read(file)
+#' eem <- eem_read(file, import_function = "cary")
 #'
 #' eem_coble_peaks(eem)
-#'
 #' @export
-eem_coble_peaks <- function(eem, verbose = TRUE){
-
+eem_coble_peaks <- function(eem, verbose = TRUE) {
   stopifnot(.is_eemlist(eem) | .is_eem(eem))
 
   ## It is a list of eems, then call lapply
-  if(.is_eemlist(eem)){
-
+  if (.is_eemlist(eem)) {
     res <- lapply(eem, eem_coble_peaks, verbose = verbose)
     res <- dplyr::bind_rows(res)
 
@@ -103,10 +94,8 @@ eem_coble_peaks <- function(eem, verbose = TRUE){
 
   coble_ex_peak <- list(b = 275, t = 275, a = 260, m = 312, c = 350)
 
-  if(!all(coble_ex_peak %in% eem$ex) & verbose){
-
+  if (!all(coble_ex_peak %in% eem$ex) & verbose) {
     warning(msg_warning_wavelength(), call. = FALSE)
-
   }
 
   ## Get the peaks
@@ -114,25 +103,89 @@ eem_coble_peaks <- function(eem, verbose = TRUE){
 
   t <- pracma::interp2(eem$ex, eem$em, eem$x, 275, 340)
 
-  a <- max(pracma::interp2(eem$ex, eem$em, eem$x,
-                           rep(260, length(380:460)), 380:460))
+  a <- max(pracma::interp2(
+    eem$ex, eem$em, eem$x,
+    rep(260, length(380:460)), 380:460
+  ))
 
-  m <- max(pracma::interp2(eem$ex, eem$em, eem$x,
-                           rep(312, length(380:420)), 380:420))
+  m <- max(pracma::interp2(
+    eem$ex, eem$em, eem$x,
+    rep(312, length(380:420)), 380:420
+  ))
 
-  c <- max(pracma::interp2(eem$ex, eem$em, eem$x,
-                           rep(350, length(420:480)), 420:480))
+  c <- max(pracma::interp2(
+    eem$ex, eem$em, eem$x,
+    rep(350, length(420:480)), 420:480
+  ))
 
   #--------------------------------------------
   # Return the data
   #--------------------------------------------
-  return(data.frame(sample = eem$sample,
-                    b = b,
-                    t = t,
-                    a = a,
-                    m = m,
-                    c = c,
-                    stringsAsFactors = FALSE))
+  return(data.frame(
+    sample = eem$sample,
+    b = b,
+    t = t,
+    a = a,
+    m = m,
+    c = c,
+    stringsAsFactors = FALSE
+  ))
+}
+
+#' Extract fluorescence peaks
+#'
+#' @param ex A numeric vector with excitation wavelengths.
+#' @param em A numeric vector with emission wavelengths.
+#'
+#' @template template_eem
+#'
+#' @template template_section_interp2
+#'
+#' @return A data frame containing excitation and emission peak values. See
+#'   details for more information.
+#'
+#' @importFrom purrr map2
+#' @importFrom assertthat assert_that
+#'
+#' @examples
+#' file <- system.file("extdata/cary/scans_day_1/", "sample1.csv", package = "eemR")
+#' eem <- eem_read(file, import_function = "cary")
+#'
+#' eem_peaks(eem, ex = c(250, 350), em = c(300, 400))
+#' @export
+eem_peaks <- function(eem, ex, em, verbose = TRUE) {
+  stopifnot(.is_eemlist(eem) | .is_eem(eem))
+  stopifnot(
+    is.numeric(ex),
+    is.numeric(em),
+    length(ex) == length(em),
+    all(ex > 0),
+    all(em > 0)
+  )
+
+  ## It is a list of eems, then call lapply
+  if (.is_eemlist(eem)) {
+    res <- lapply(eem, eem_peaks, ex, em, verbose = verbose)
+    res <- dplyr::bind_rows(res)
+
+    return(res)
+  }
+
+  assertthat::assert_that(all(dplyr::between(ex, range(eem$ex)[1], range(eem$ex)[2])), msg = "Excitation values are not within the range of excitation values of the EEM.")
+  assertthat::assert_that(all(dplyr::between(em, range(eem$em)[1], range(eem$em)[2])), msg = "Emission values are not within the range of emission values of the EEM.")
+
+  peak_intensity <- purrr::map2(ex, em, function(ex, em) {
+    pracma::interp2(eem$ex, eem$em, eem$x, ex, em)
+  })
+
+  peak_intensity <- unlist(peak_intensity)
+
+  return(data.frame(
+    sample = eem$sample,
+    ex = ex,
+    em = em,
+    peak_intensity = peak_intensity
+  ))
 }
 
 #' Calculate the fluorescence humification index (HIX)
@@ -159,18 +212,17 @@ eem_coble_peaks <- function(eem, verbose = TRUE){
 #' @export
 #' @examples
 #' file <- system.file("extdata/cary/scans_day_1/", package = "eemR")
-#' eem <- eem_read(file)
+#' eem <- eem_read(file, import_function = "cary")
 #'
 #' eem_humification_index(eem)
-#'
 eem_humification_index <- function(eem, scale = FALSE, verbose = TRUE) {
-
-  stopifnot(.is_eemlist(eem) | .is_eem(eem),
-            is.logical(scale))
+  stopifnot(
+    .is_eemlist(eem) | .is_eem(eem),
+    is.logical(scale)
+  )
 
   ## It is a list of eems, then call lapply
-  if(.is_eemlist(eem)){
-
+  if (.is_eemlist(eem)) {
     res <- lapply(eem, eem_humification_index, verbose = verbose, scale = scale)
     res <- dplyr::bind_rows(res)
 
@@ -181,30 +233,28 @@ eem_humification_index <- function(eem, scale = FALSE, verbose = TRUE) {
   # Get the data and calculate the humification index (HIX)
   #---------------------------------------------------------------------
 
-  if(!254 %in% eem$ex & verbose){
-
+  if (!254 %in% eem$ex & verbose) {
     warning(msg_warning_wavelength(), call. = FALSE)
-
   }
 
   em_435_480 <- seq(from = 435, to = 480, by = 1)
   em_300_345 <- seq(from = 300, to = 345, by = 1)
   ex_254 <- rep(254, length(em_300_345))
 
-  sum_em_435_480 <- sum(pracma::interp2(eem$ex, eem$em, eem$x,
-                                        ex_254, em_435_480))
+  sum_em_435_480 <- sum(pracma::interp2(
+    eem$ex, eem$em, eem$x,
+    ex_254, em_435_480
+  ))
 
-  sum_em_300_345 <- sum(pracma::interp2(eem$ex, eem$em, eem$x,
-                                        ex_254, em_300_345))
-
-  if(scale){
+  sum_em_300_345 <- sum(pracma::interp2(
+    eem$ex, eem$em, eem$x,
+    ex_254, em_300_345
+  ))
 
+  if (scale) {
     hix <- sum_em_435_480 / (sum_em_300_345 + sum_em_435_480)
-
-  }else{
-
+  } else {
     hix <- sum_em_435_480 / sum_em_300_345
-
   }
 
   return(data.frame(sample = eem$sample, hix = hix, stringsAsFactors = FALSE))
@@ -231,17 +281,14 @@ eem_humification_index <- function(eem, scale = FALSE, verbose = TRUE) {
 #' @export
 #' @examples
 #' file <- system.file("extdata/cary/scans_day_1/", package = "eemR")
-#' eem <- eem_read(file)
+#' eem <- eem_read(file, import_function = "cary")
 #'
 #' eem_biological_index(eem)
-#'
 eem_biological_index <- function(eem, verbose = TRUE) {
-
   stopifnot(.is_eemlist(eem) | .is_eem(eem))
 
   ## It is a list of eems, then call lapply
-  if(.is_eemlist(eem)){
-
+  if (.is_eemlist(eem)) {
     res <- lapply(eem, eem_biological_index, verbose = verbose)
     res <- dplyr::bind_rows(res)
 
@@ -252,7 +299,7 @@ eem_biological_index <- function(eem, verbose = TRUE) {
   # Get the data and calculate the biological index (BIX)
   #---------------------------------------------------------------------
 
-  if(!all(310 %in% eem$ex & c(380, 430) %in% eem$em) & verbose){
+  if (!all(310 %in% eem$ex & c(380, 430) %in% eem$em) & verbose) {
     warning(msg_warning_wavelength(), call. = FALSE)
   }
 
